about summary refs log tree commit diff
path: root/src/tools/compiletest
diff options
context:
space:
mode:
authorAlex Crichton <alex@alexcrichton.com>2016-04-19 09:44:19 -0700
committerAlex Crichton <alex@alexcrichton.com>2016-04-19 09:57:00 -0700
commitcbe6292c58feb643917c0959f95173a3c312fbd4 (patch)
tree7cbc1d60e2ae6fd48b65025aebc5a2e1034ca5bf /src/tools/compiletest
parent9db6a41687bacde82585f127b43d418d5845e5c7 (diff)
downloadrust-cbe6292c58feb643917c0959f95173a3c312fbd4.tar.gz
rust-cbe6292c58feb643917c0959f95173a3c312fbd4.zip
mk: Force system python for LLDB tests on OSX
Force usage of /usr/bin/python whenever we run LLDB tests on OSX because it
looks like no other Python will work.
Diffstat (limited to 'src/tools/compiletest')
-rw-r--r--src/tools/compiletest/src/common.rs7
-rw-r--r--src/tools/compiletest/src/main.rs6
-rw-r--r--src/tools/compiletest/src/runtest.rs4
3 files changed, 11 insertions, 6 deletions
diff --git a/src/tools/compiletest/src/main.rs b/src/tools/compiletest/src/main.rs
index e92b0c87280..6cfe1de2650 100644
--- a/src/tools/compiletest/src/main.rs
+++ b/src/tools/compiletest/src/main.rs
@@ -70,7 +70,8 @@ pub fn parse_config(args: Vec<String> ) -> Config {
           reqopt("", "run-lib-path", "path to target shared libraries", "PATH"),
           reqopt("", "rustc-path", "path to rustc to use for compiling", "PATH"),
           reqopt("", "rustdoc-path", "path to rustdoc to use for compiling", "PATH"),
-          reqopt("", "python", "path to python to use for doc tests", "PATH"),
+          reqopt("", "lldb-python", "path to python to use for doc tests", "PATH"),
+          reqopt("", "docck-python", "path to python to use for doc tests", "PATH"),
           optopt("", "valgrind-path", "path to Valgrind executable for Valgrind tests", "PROGRAM"),
           optflag("", "force-valgrind", "fail if Valgrind tests cannot be run under Valgrind"),
           optopt("", "llvm-filecheck", "path to LLVM's FileCheck binary", "DIR"),
@@ -140,7 +141,8 @@ pub fn parse_config(args: Vec<String> ) -> Config {
         run_lib_path: make_absolute(opt_path(matches, "run-lib-path")),
         rustc_path: opt_path(matches, "rustc-path"),
         rustdoc_path: opt_path(matches, "rustdoc-path"),
-        python: matches.opt_str("python").unwrap(),
+        lldb_python: matches.opt_str("lldb-python").unwrap(),
+        docck_python: matches.opt_str("docck-python").unwrap(),
         valgrind_path: matches.opt_str("valgrind-path"),
         force_valgrind: matches.opt_present("force-valgrind"),
         llvm_filecheck: matches.opt_str("llvm-filecheck").map(|s| PathBuf::from(&s)),
diff --git a/src/tools/compiletest/src/runtest.rs b/src/tools/compiletest/src/runtest.rs
index 6358d19ff09..2336727759a 100644
--- a/src/tools/compiletest/src/runtest.rs
+++ b/src/tools/compiletest/src/runtest.rs
@@ -776,7 +776,7 @@ fn run_debuginfo_lldb_test(config: &Config, props: &TestProps, testpaths: &TestP
         let lldb_script_path = rust_src_root.join("src/etc/lldb_batchmode.py");
         cmd2procres(config,
                     testpaths,
-                    Command::new(&config.python)
+                    Command::new(&config.lldb_python)
                             .arg(&lldb_script_path)
                             .arg(test_executable)
                             .arg(debugger_script)
@@ -1901,7 +1901,7 @@ fn run_rustdoc_test(config: &Config, props: &TestProps, testpaths: &TestPaths) {
 
     let res = cmd2procres(config,
                           testpaths,
-                          Command::new(&config.python)
+                          Command::new(&config.docck_python)
                                   .arg(root.join("src/etc/htmldocck.py"))
                                   .arg(out_dir)
                                   .arg(&testpaths.file));
diff --git a/src/tools/compiletest/src/common.rs b/src/tools/compiletest/src/common.rs
index 6ffc1e9ea11..81265f6ccaf 100644
--- a/src/tools/compiletest/src/common.rs
+++ b/src/tools/compiletest/src/common.rs
@@ -83,8 +83,11 @@ pub struct Config {
     // The rustdoc executable
     pub rustdoc_path: PathBuf,
 
-    // The python executable
-    pub python: String,
+    // The python executable to use for LLDB
+    pub lldb_python: String,
+
+    // The python executable to use for htmldocck
+    pub docck_python: String,
 
     // The llvm FileCheck binary path
     pub llvm_filecheck: Option<PathBuf>,